/'
	===================================================================================
	
		FB.Packer - FreeBASIC Package Manager
		
		http://code.google.com/p/fbpacker/
	
	-----------------------------------------------------------------------------------
	
		version:	1.3
	
		author:	Aleksandar Ruzicic (krckoorascic@gmail.com)
	
	-----------------------------------------------------------------------------------
	
		Copyright (c) 2008 Aleksandar Ruzicic
	
		Permission is hereby granted, free of charge, to any person obtaining a copy
		of this software and associated documentation files (the "Software"), to deal
		in the Software without restriction, including without limitation the rights
		to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
		copies of the Software, and to permit persons to whom the Software is
		furnished to do so, subject to the following conditions:
		
		The above copyright notice and this permission notice shall be included in
		all copies or substantial portions of the Software.
		
		THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
		IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
		FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
		AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
		LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
		OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
		THE SOFTWARE. 

	===================================================================================
'/

#Ifndef __FB_PACKER__
#Define __FB_PACKER__
	
	#Include "fbgfx.bi"
	
	#Inclib "fbpacker"
	
	Namespace FB
	
		Declare Sub Scramble(ptrData As UByte Pointer, length As Integer, password As String)
		
		Declare Function Adler32(ptrData As UByte Pointer, length As Integer) As UInteger
		Declare Function SuperFastHash(ptrData As UByte Pointer, length As Integer) As UInteger
		
		Type CryptFunction As Sub(ptrData As UByte Pointer, length As Integer, password As String)
		Type ChecksumFunction As Function(ptrData As UByte Pointer, length As Integer) As UInteger
		
		
		Namespace Encrypt
			
			Static Shared As FB.CryptFunction		Scramble = ProcPtr(FB.Scramble)
			
		End Namespace
		
		Namespace Decrypt
			
			Static Shared As FB.CryptFunction		Scramble = ProcPtr(FB.Scramble)
			
		End Namespace
		
		Namespace Checksum
			
			Static Shared As FB.ChecksumFunction	Adler32 = ProcPtr(FB.Adler32)
			Static Shared As FB.ChecksumFunction	SuperFastHash = ProcPtr(FB.SuperFastHash)
			
		End Namespace
		
		
		Type PackerItem
			Name		As String
			Data		As UByte Ptr = 0
			Length	As UInteger = 0
			Compress	As Integer = -1
		End Type
		
		Type Packer
						
			Declare Sub AddFile(Name As String, Filename As String, Compress As Integer = -1)
			Declare Sub AddFile(Name As String, pData As UByte Pointer, length As UInteger, Compress As Integer = -1)
			Declare Sub AddImage(Name As String, image As FB.IMAGE Pointer, Compress As Integer = -1)
			Declare Sub AddBMPImage(ItemName As String, image As String, Compress As Integer = -1)
			
			Declare Sub ExtractFile(Name As String, OutputFile As String)
			Declare Sub ExtractFile(Index As Integer, OutputFile As String)
			Declare Sub ExtractFile(Name As String, ByRef pData As UByte Pointer, ByRef length As UInteger)
			Declare Sub ExtractFile(Index As Integer, ByRef pData As UByte Pointer, ByRef length As UInteger)
			Declare Function ExtractImage(Name As String) As FB.IMAGE Pointer
			Declare Function ExtractImage(Index As Integer) As FB.IMAGE
			
			Declare Property ItemCount As UInteger
			
			Declare Property Item(Index As UInteger) As PackerItem Pointer
			Declare Property Item(Name As String) As PackerItem Pointer
			
			Declare Sub Remove(Name As String)
			Declare Sub Clear
			
			Declare Function Save(Filename As String, Password As String) As Integer
			Declare Function Load(Filename As String, Password As String) As Integer
			
			Encrypt	As CryptFunction = FB.Encrypt.Scramble
			Decrypt	As CryptFunction = FB.Decrypt.Scramble
			
			Checksum	As ChecksumFunction = FB.Checksum.Adler32
			
			Declare Destructor
			Declare Constructor

			__dont_use_this_member__ As Any Pointer			

		End Type
	
	End Namespace
	
#EndIf