/'  
	FastLZ - lightning-fast lossless compression library
	
	Copyright (C) 2007 Ariya Hidayat (ariya@kde.org)
	Copyright (C) 2006 Ariya Hidayat (ariya@kde.org)
	Copyright (C) 2005 Ariya Hidayat (ariya@kde.org)
	
	Permission is hereby granted, free of charge, to any person obtaining a copy
	of this software and associated documentation files (the "Software"), to deal
	in the Software without restriction, including without limitation the rights
	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
	copies of the Software, and to permit persons to whom the Software is
	furnished to do so, subject to the following conditions:
	
	The above copyright notice and this permission notice shall be included in
	all copies or substantial portions of the Software.
	
	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
	THE SOFTWARE.
'/

'
'  C header translated to FreeBASIC by Aleksandar Ruzicic
'

#Ifndef FASTLZ_BI
#Define FASTLZ_BI

#Define FASTLZ_VERSION 0x000100

#Define FASTLZ_VERSION_MAJOR     0
#Define FASTLZ_VERSION_MINOR     1	' in C header this is set to 0
#Define FASTLZ_VERSION_REVISION  0

#Define FASTLZ_VERSION_STRING "0.1.0"

Extern "C"
	
	/'
	  Compress a block of data in the input buffer and returns the size of 
	  compressed block. The size of input buffer is specified by length. The 
	  minimum input buffer size is 16.
	
	  The output buffer must be at least 5% larger than the input buffer  
	  and can not be smaller than 66 bytes.
	
	  If the input is not compressible, the return value might be larger than
	  length (input buffer size).
	
	  The input buffer and the output buffer can not overlap.
	'/
	
	Declare Function fastlz_compress Alias "fastlz_compress" 		_
										( 												_
											 	input 	As Any Pointer, 		_
											 	length 	As Integer, 			_
											 	output 	As Any Pointer 		_
										) 					As Integer 
		
	/'
	  Decompress a block of compressed data and returns the size of the 
	  decompressed block. If error occurs, e.g. the compressed data is 
	  corrupted or the output buffer is not large enough, then 0 (zero) 
	  will be returned instead.
	
	  The input buffer and the output buffer can not overlap.
	
	  Decompression is memory safe and guaranteed not to write the output buffer
	  more than what is specified in maxout.
	'/
	
	Declare Function fastlz_decompress Alias "fastlz_decompress"	_ 
										( 												_
												input 	As Any Pointer, 		_
												length 	As Integer, 			_
												output 	As Any Pointer, 		_
												maxout 	As Integer				_
										) 					As Integer 
	
	/'
	  Compress a block of data in the input buffer and returns the size of 
	  compressed block. The size of input buffer is specified by length. The 
	  minimum input buffer size is 16.
	
	  The output buffer must be at least 5% larger than the input buffer  
	  and can not be smaller than 66 bytes.
	
	  If the input is not compressible, the return value might be larger than
	  length (input buffer size).
	
	  The input buffer and the output buffer can not overlap.
	
	  Compression level can be specified in parameter level. At the moment, 
	  only level 1 and level 2 are supported.
	  Level 1 is the fastest compression and generally useful for short data.
	  Level 2 is slightly slower but it gives better compression ratio.
	
	  Note that the compressed data, regardless of the level, can always be
	  decompressed using the function fastlz_decompress above.
	'/  
	
	Declare Function fastlz_compress_level Alias "fastlz_compress_level" _
										(														_
												level 	As Integer, 					_
												input 	As Any Pointer, 				_
												length 	As Integer, 					_
												output 	As Any Pointer					_
										) 					As Integer 
	
	
	'' use this macro to calculate output buffer size (for fastlz_compress and fastlz_compress_level)
	#Define FASTLZ_BUFFER_SIZE(n) IIf((n) < 66, 70, CInt((n) * 1.05))
	
End Extern

#EndIf /' FASTLZ_BI '/
